@@ -2,20 +2,9 @@
 import os
 
 
-def set_ver(hub):
-    """
-    Set the version to the <project name>/version.py
-    """
-    ver = hub.OPT["pop_release"]["ver"]
-    name = hub.pop_release.PATHNAME
-    ver_str = f'# -*- coding: utf-8 -*-\nversion = "{ver}"\n'
-    path = os.path.join(name, "version.py")
-    with open(path, "w+") as wfh:
-        wfh.write(ver_str)
-
-
 def set_doc(hub):
     """
+    Set the version on the docs
     """
     ver = hub.OPT["pop_release"]["ver"]
     name = hub.pop_release.PATHNAME
@@ -31,12 +20,24 @@ def set_doc(hub):
     with open(path, "r") as rfh:
         for line in rfh.readlines():
             if line.startswith("ver"):
-                lines.append(f'version = "{ver}"')
+                lines.append(f'version = "{ver}"\n')
                 continue
             elif line.startswith("release"):
-                lines.append(f'release = "{ver}"')
+                lines.append(f'release = "{ver}"\n')
                 continue
             else:
                 lines.append(line)
     with open(path, "w+") as wfh:
         wfh.writelines(lines)
+
+
+def set_ver(hub):
+    """
+    Set the version to the <project name>/version.py
+    """
+    ver = hub.OPT["pop_release"]["ver"]
+    name = hub.pop_release.PATHNAME
+    ver_str = f'# -*- coding: utf-8 -*-\nversion = "{ver}"\n'
+    path = os.path.join(name, "version.py")
+    with open(path, "w+") as wfh:
+        wfh.write(ver_str)
